@@ -17,8 +17,12 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
+
+from typing import List
+from dataclasses import dataclass
 from bs4 import BeautifulSoup
 
+
 from iservscrapping.base import BaseIserv
 from iservscrapping.task import Task
 from iservscrapping.untis_scrapper import UntisScrapper
@@ -26,6 +30,17 @@ from iservscrapping.untis_scrapper import UntisScrapper
 numbers = ["1", "2", "3", "4", "5", "6", "7", "8", "9", "0"]
 
 
+@dataclass
+class Classtest:
+    """Contains data about a classtest or event
+    """
+    date: str
+    time: str
+    name: str
+    course: str
+    kind: str
+
+
 class Iserv(BaseIserv):
     """
     The main class you will want to use most of the time. Provides all the scrapping functions.
@@ -75,7 +90,7 @@ class Iserv(BaseIserv):
             test_list.append(i.text)
         return test_list
 
-    def get_next_tests(self, path="/iserv"):
+    def get_next_tests(self, path="/iserv") -> List[Classtest]:
         """
         Args:
             path (:obj:`str`, optional): The path where the tests box is located. Defaults to /iserv
@@ -90,12 +105,17 @@ class Iserv(BaseIserv):
         tests = soup.find("ul", "pl mb0")
 
         for i in tests.find_all("li"):
-            entry = {}
             parsed = i.text.split(" - ")
-            entry['date'] = parsed[0].strip()
-            entry['time'] = parsed[1].strip()
-            entry['class'] = parsed[2].strip()
-            entry['subject'] = parsed[3].strip()
+
+            title_and_kind: List[str] = parsed[3].strip().split("(")
+
+            entry = Classtest(
+                date=parsed[0].strip(),
+                time=parsed[1].strip(),
+                course=parsed[2].strip(),
+                kind=title_and_kind.pop()[:-1],
+                name="(".join(title_and_kind)
+            )
             test_list.append(entry)
         return test_list
 
@@ -119,7 +139,8 @@ class Iserv(BaseIserv):
             if len(columns) == 7:
                 current_task = Task(self.url, self.username, self.password)
                 current_task.title = columns[0].find("a").text
-                current_task.id = int(columns[0].find("a")["href"].split("/")[-1])
+                current_task.id = int(columns[0].find("a")[
+                                      "href"].split("/")[-1])
                 current_task.start_date = columns[1].text
                 current_task.end_date = columns[2].text
                 if columns[4].find("span", {"class": "glyphicon-ok"}):
