@@ -39,9 +39,9 @@ class SubstitutionEntry:
 @dataclass
 class CourseHeading:
     """Represents one Course in the substitution plan and contains the rows."""
+    name: str
     entrys: List[SubstitutionEntry]
 
-
 @dataclass
 class SubstitutionPlanMetaTable:
     """Represents information from the table at the top of the plan"""
@@ -108,7 +108,7 @@ class UntisScrapper:
                 parsed_row = SubstitutionEntry(
                     time="", subject="", teacher="", courses=[], room="", text=None)
                 if current_class not in parsed_plan.keys():
-                    parsed_plan[current_class] = []
+                    parsed_plan[current_class] = CourseHeading(current_class, [])
                 for i, column in enumerate(row):
                     if i == 0:
                         parsed_row.time = column.text.strip()
@@ -122,7 +122,7 @@ class UntisScrapper:
                         parsed_row.courses = column.text.strip()
                     elif i == 5:
                         parsed_row.room = column.text.strip()
-                parsed_plan[current_class].append(parsed_row)
+                parsed_plan[current_class].entrys.append(parsed_row)
             elif len(row) == 1:
                 first_element = list(row)[0]
                 if isinstance(first_element, element.Tag):
